% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %                                                                            %
% %    function [x, t] = Euler (deriv, d, N, dt, x_0);                         %
% %                                                                            %
% %    INPUTS:                                                                 %
% %                                                                            %
% %    @deriv    specifies the script of the derivative, e.g. @LorenzODE_B     %
% %    d         dimension                                                     %
% %    N         number of datapoints                                          %
% %    dt        time step                                                     %
% %    x_0       initial conditions (column vector of dimension d)             %
% %                                                                            %
% %    OUTPUTS:                                                                %
% %                                                                            %
% %    x         function  (matrix of dimensions d,N)                          %
% %    t         time line (row vector of dimension N)                         %
% %                                                                            %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [x, t] = Euler (deriv, d, N, dt, x_0)

% define time line

    t      = 0:dt:(N-1)*dt;
    
% allocate function values and initialize    
    
    x      = zeros(d,N);
    x(:,1) = x_0;

% loop over all time points
    
    for n = 2:N
        x(:,n) = x(:,n-1) + dt*feval(deriv,x(:,n-1));;
    end    

end

