% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %                                                                       %
% %    Matlab script for lecture                                          %
% %    "Simple differential equations - introduction using Matlab"        %
% %    by Christian Rummel                                                %
% %                                                                       %
% %    BENESCO lecture series                                             %
% %    "Signal Analysis and Brain Oscillations in Health and Disease"     %
% %    Bern, 2017/11/24                                                   %
% %                                                                       %
% %    Script demonstrates integration of the FitzHugh-Nagumo ODE.        %
% %                                                                       %
% %    written by C. Rummel, 2017/11/20                                   %
% %                                                                       %
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
close all
clc

% parameters of the integrator

d      =     2              % dimension of time series
N      = 10000              % length of time series
dt     =     0.1            % integration step

% define parameters for usage also in function for derivative 

global alpha epsilon gamma v_eq

alpha   = -0.139;
epsilon =  0.008;
gamma   =  1.5;
v_eq    =  0.0;

% initialize

x_0    = [0 -0.07];
% x_0    = 0.1*randn(1,d);

% integrate FitzHugh-Nagumo system

[x, t] = RungeKutta4 (@FitzHughNagumo1, d, N, dt, x_0);

% display attractor in 2D

figure(10)
plot (x(1,:),x(2,:));

% display time series of v- and w-coordinate

figure(20)
for i = 1:d
    subplot(d,1,i);
    plot(t,x(i,:));
end


